<?php
/**
 * Blook functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Blook
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

if ( ! function_exists( 'blook_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function blook_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Blook, use a find and replace
		 * to change 'blook' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'blook', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(array(
		    'blook-top-nav' => esc_html__('Top Menu', 'blook'),
		    'blook-primary-nav' => esc_html__('Primary Menu', 'blook'),
		    'blook-footer-nav' => esc_html__('Footer Menu', 'blook'),
		));
		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'blook_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		/*
		 * Posts Format.
		 *
		 * https://wordpress.org/support/article/post-formats/
		 */
		add_theme_support( 'post-formats', array(
		    'video',
		    'audio',
		    'gallery',
		    'quote',
		    'image'
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);

		
	    /*
	    * Add theme support for gutenberg block
	    */
	    add_theme_support( 'align-wide' );
        add_theme_support( 'responsive-embeds' );

	}
endif;
add_action( 'after_setup_theme', 'blook_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function blook_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'blook_content_width', 640 );
}
add_action( 'after_setup_theme', 'blook_content_width', 0 );


/**
 * function for google fonts
 */
if (!function_exists('blook_fonts_url')) :

    /**
     * Return fonts URL.
     *
     * @since 1.0.0
     * @return string Fonts URL.
     */
    function blook_fonts_url()
    {
    	$fonts_url = '';
    	$fonts     = array();

    	$blook_primary_font = 'Josefin+Sans';
    	$blook_secondary_font = 'Libre+Franklin:ital,wght@0,300;0,400;0,500;0,600;0,700;0,800;1,300;1,400;1,500;1,600;1,700';

    	$blook_fonts = array();
    	$blook_fonts[]=$blook_primary_font;
    	$blook_fonts[]=$blook_secondary_font;

    	  $blook_fonts_stylesheet = '//fonts.googleapis.com/css?family=';

    	  $i  = 0;
    	  for ($i=0; $i < count( $blook_fonts ); $i++) { 

    	    if ( 'off' !== sprintf( _x( 'on', '%s font: on or off', 'blook' ), $blook_fonts[$i] ) ) {
    	    $fonts[] = $blook_fonts[$i];
    	  }

    	  }

    	if ( $fonts ) {
    	  $fonts_url = add_query_arg( array(
    	    'family' => urldecode( implode( '|', $fonts ) ),
    	  ), 'https://fonts.googleapis.com/css' );
    	}

    	return $fonts_url;
    }
endif;


/**
 * Enqueue scripts and styles.
 */
function blook_scripts() {
	$fonts_url = blook_fonts_url();
	if (!empty($fonts_url)) {
	    wp_enqueue_style('blook-google-fonts', $fonts_url, array(), null);
	}
	wp_enqueue_style( 'blook-style', get_stylesheet_uri(), array(), _S_VERSION );
    wp_add_inline_style('blook-style', blook_color_typo_css());

	// STYLE
	wp_enqueue_style( 'slick', get_template_directory_uri() . '/assets/resources/slick/css/slick.min.css');
    wp_enqueue_style( 'ionicons', get_template_directory_uri() . '/assets/resources/ionicons/css/ionicons.min.css');
    wp_enqueue_style( 'magnific', get_template_directory_uri() . '/assets/resources/magnific/css/magnific-popup.css');
	
	// SCRIPT
	wp_enqueue_script( 'blook-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );
	wp_enqueue_script( 'slick', get_template_directory_uri() . '/assets/resources/slick/js/slick.js', array(), _S_VERSION, true );
	wp_enqueue_script( 'theiaStickySidebar', get_template_directory_uri() . '/assets/resources/theiaStickySidebar/theia-sticky-sidebar.min.js', array(), _S_VERSION, true );
	wp_enqueue_script( 'magnific', get_template_directory_uri() . '/assets/resources/magnific/js/jquery.magnific-popup.js', array(), _S_VERSION, true );
	wp_enqueue_script( 'blook-main', get_template_directory_uri() . '/assets/js/main.js',  array( 'jquery' ), _S_VERSION, true );


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	$ajax_nonce = wp_create_nonce('blook_ajax_nonce');
    wp_localize_script(
        'blook-main', 
        'blook_main',
        array(
            'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
            'loadmore'   => esc_html__( 'Load More', 'blook' ),
            'nomore'     => esc_html__( 'No More Posts', 'blook' ),
            'loading'    => esc_html__( 'Loading...', 'blook' ),
            'ajax_nonce'    => $ajax_nonce,
         )
    );

}
add_action( 'wp_enqueue_scripts', 'blook_scripts' );

/**
 * Admin enqueue script
 */
function blook_admin_scripts($hook){

	wp_enqueue_media();
    wp_enqueue_style('blook-admin', get_template_directory_uri() . '/assets/css/admin.css');
    wp_enqueue_script('blook-admin', get_template_directory_uri() . '/assets/js/admin.js', array('jquery'), '', 1);

    $ajax_nonce = wp_create_nonce('blook_ajax_nonce');

    wp_localize_script( 
        'blook-admin', 
        'blook_admin',
        array(
            'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
            'ajax_nonce' => $ajax_nonce,
            'active' => esc_html__('Active','blook'),
	        'deactivate' => esc_html__('Deactivate','blook'),
	        'upload_image'   =>  esc_html__('Choose Image','blook'),
            'use_imahe'   =>  esc_html__('Select','blook'),
         )
    );

}

add_action('admin_enqueue_scripts', 'blook_admin_scripts');

/**
 * Implement the Custom widget feature.
 */
require get_template_directory() . '/inc/widget-init.php';
/**
 * Implement the TGM feature.
 */
require get_template_directory() . '/assets/resources/TGM-plugin-activation/recommended-plugin.php';

/**
 * Implement recomended plugin booster extention.
 */
if(class_exists( 'Booster_Extension_Class' ) ){
	require get_template_directory() . '/inc/blook-booster-extention.php';
}

/**
 * Implement the Custom Header/Footer feature.
 */
require get_template_directory() . '/inc/components/header-component.php';
require get_template_directory() . '/inc/components/footer-component.php';

/**
 * color and typo option.
 */
require get_template_directory() . '/inc/components/front-page-component-1.php';
require get_template_directory() . '/inc/components/front-page-component-2.php';
require get_template_directory() . '/inc/components/front-page-component-3.php';
require get_template_directory() . '/inc/components/front-page-component-4.php';
require get_template_directory() . '/inc/components/front-page-component-5.php';
require get_template_directory() . '/inc/components/color-typo.php';
require get_template_directory() . '/inc/components/breaking-news.php';
require get_template_directory() . '/inc/custom-functions.php';
require get_template_directory() . '/inc/single-related-post.php';
require get_template_directory() . '/inc/metabox.php';
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * about page on theme activation.
 */
require get_template_directory() . '/inc/about/about.php';
require get_template_directory() . '/inc/about/blook-plugin.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}
add_filter('wp_nav_menu_items', 'blook_nav_home', 1, 2);
function blook_nav_home($items, $args){
    if( $args->theme_location == 'blook-primary-nav' ){
        $item = '<li class="brand-home"><a title="Home" href="'. esc_url( home_url() ) .'">' . "<i class='ion ion-ios-home'></i>" . '</a></li>';
        $items = $item . $items;
    }
    return $items;
}

add_filter( 'walker_nav_menu_start_el', 'blook_add_description', 10, 4);
function blook_add_description( $item_output, $item, $depth, $args ) {
    $description = $item->post_content;
    if (('' !== $description) && (' ' !== $description) ) {
        return preg_replace( '/(<a.*)</', '$1' . '<span class="menu-description">' . $description . '</span><', $item_output) ;
    }
    else {
        return $item_output;
    };
}