<?php
/**
 * Implement theme front page section.
 *
 * @package Blook
 */

if (!function_exists('blook_front_page_component_1')):
    /**
     * Front/Page Style 1
     *
     * @since Blook 1.0.0
     *
     */
    function blook_front_page_component_1()
    { 
        if (1 != blook_get_option('enable_component_1')) {
            return null;
        }
        ?>
        <div class="blook-frontpage-layout-1-section">
            <div class="blook-container">
                <div class="blook-row">
                    <!-- component - 1 popular post section -->
                    <div class="blook-col blook-col-xs-6 blook-col-lg-4 order-1 sticky-component-1">
                        <div class="blook-popular-post-list blook-post-layout-1">
                            <?php if (!empty(blook_get_option('blook_recent_post_section_title'))) { ?>
                                <h2 class="blook-section-title"><?php echo esc_html(blook_get_option('blook_recent_post_section_title')); ?></h2>
                            <?php } ?>
                            <?php blook_component_1_popular_post(); ?>
                        </div>
                    </div>
                    <!-- component - grid post section -->
                    <div class="blook-col   blook-col-lg-4 order-2 sticky-component-1">
                        <div class="blook-grid-post-list">
                            <?php if (!empty(blook_get_option('blook_post_grid_section'))) { ?>
                                <h2 class="blook-section-title blook-section-title-style-1"><span><?php echo esc_html(blook_get_option('blook_post_grid_section')); ?></span></h2>
                            <?php } ?>
                            <div class="ajax-post-load blook-row">
                                <?php blook_component_1_post_grid(); ?>
                            </div>
                            <div class="blook-btn-section">
                                <a href="javascript:void(0)" class="blook-btn blook-btn-style-1 blook-btn-rounded blook-btn-primary load-posts-btn">
                                    <span><?php echo esc_html('Load More Posts','blook'); ?></span>
                                </a>
                            </div>
                        </div>
                    </div>
                    <!-- component - slider post -->
                    <div class="blook-col blook-col-xs-6 order-3 blook-col-lg-4 sticky-component-1">
                        <div class="blook-slider-post-list blook-single-slider">
                            <?php blook_component_1_post_slider(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
   <?php }
endif;

add_action('blook_action_front_page_component_1', 'blook_front_page_component_1', 10);

// popular post
if (!function_exists('blook_component_1_popular_post')) :
    /**
     * Component-1 Popular Post
     *
     * @since Blook 1.0.0
     *
     */
    function blook_component_1_popular_post()
    {
        $post_category = esc_attr(blook_get_option('select_category_for_recent_post_section'));
        $number_of_post = absint(blook_get_option('number_of_home_recent_post_section'));
        $counter = 1;
        $image_url = '';
        $get_posts = blook_get_post_query($number_of_post, $post_category);
        if ($get_posts->have_posts()) :
            while ($get_posts->have_posts()) : $get_posts->the_post();
                if (has_post_thumbnail()) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'medium_large');
                    $image_url = $image['0'];
                }
            ?>

            <div class="blook-post blook-post-style-1">
                <div class="blook-image-section">
                    <a href="<?php the_permalink(); ?>"></a>
                    <span class="blook-counter">
                        <?php echo absint($counter); ?>
                    </span>
		            <div class="blook-image bg-image" style="background-image:url('<?php echo esc_url($image_url); ?>')"></div>
                </div><!--blook-image-section-->

                <div class="blook-desc">
                    <div class="entry-meta blook-meta-tag blook-post-content-opacity blook-text-uppercase">
                        <?php
                            blook_posted_on();
                        ?>
                    </div><!-- .entry-meta -->
                    <h3 class="blook-post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                </div><!--blook-desc-->

            </div><!--/blook-post-->

            <?php
            $counter++;
            endwhile;

        endif;
        wp_reset_postdata();
    }
endif;

 // grid post
if (!function_exists('blook_component_1_post_grid')) :
    /**
     * Component-1 Post Grid
     *
     * @since Blook 1.0.0
     *
     */
    function blook_component_1_post_grid($paged = 2)
    {
        $post_category = esc_attr(blook_get_option('select_category_for_post_grid'));
        $number_of_post = absint(blook_get_option('number_of_home_post_grid'));
        $excerpt_length = absint(blook_get_option('excerpt_home_post_grid'));
        $image_url ='';
        $get_posts = blook_get_post_query($number_of_post, $post_category,$paged);
        
        if( $get_posts->have_posts() ) :
            while ($get_posts->have_posts()) : $get_posts->the_post();
                if (has_post_thumbnail()) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'medium_large');
                    $image_url = $image['0'];
                }
                
            ?>
            <div class="blook-col blook-col-xs-6 blook-col-lg-12">
                <div class="blook-post blook-post-style-2">
                    <div class="blook-image-section blook-image-with-content blook-image-250 blook-image-border-hover-effect">
                        <a href="<?php the_permalink(); ?>"></a>
                        <div class="blook-image bg-image" style="background-image:url('<?php echo esc_url($image_url); ?>')"></div>
                        <?php echo esc_attr(blook_get_post_format(get_the_ID())); ?>
                        <div class="blook-post-desc">
                            <?php if( class_exists( 'Booster_Extension_Class' )){
                                blook_post_rating();
                                blook_post_read_time();
                            }?>
                        </div>
                    </div><!--blook-image-section-->

                    <div class="blook-post-desc blook-post-desc-center">
                        <div class="blook-categories blook-categories-with-bg blook-categories-primary-bg">
                            <?php blook_categories_as(); ?>       
                        </div>
                        <h3 class="blook-post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                        <div class="entry-meta blook-meta-tag">
                            <?php
                                blook_posted_by();
                                blook_posted_on();
                                ?>
                        </div><!-- .entry-meta -->
                       
                        <?php if (blook_get_option('enable_grid_post_excerpt') == 1) : ?>
                            <?php
                            $excerpt = blook_get_excerpt($excerpt_length, get_the_content());
                            echo wp_kses_post(wpautop($excerpt));
                            ?>
                        <?php endif; ?>
                        <!-- Social Share -->
                        <div class="blook-social-share">
                            <?php if( class_exists( 'Booster_Extension_Class' )){
                                blook_social_share_option();  
                            }?>
                        </div>
                       
                    </div><!--blook-desc-->

                </div><!--/blook-post-->
            </div>

            <?php 

            endwhile; ?>
           

        <?php
        endif;


        wp_reset_postdata();
    }
endif;

add_action('wp_ajax_blook_component_post_load', 'blook_component_post_load_callback');
add_action('wp_ajax_nopriv_blook_component_post_load', 'blook_component_post_load_callback');

if (!function_exists('blook_component_post_load_callback')) :

    // Post Ajax Call Function.
    function blook_component_post_load_callback() {

        if ( isset( $_POST['_wpnonce'] ) && wp_verify_nonce( wp_unslash( $_POST['_wpnonce'] ), 'blook_ajax_nonce' ) && isset( $_POST['page'] ) ) {

            blook_component_1_post_grid( $_POST['page'] );

        }
        die();

    }

endif;

// slider post
if (!function_exists('blook_component_1_post_slider')) :
    /**
     * Component-1 Post Slider
     *
     * @since Blook 1.0.0
     *
     */
    function blook_component_1_post_slider()
    {
        $post_category = esc_attr(blook_get_option('select_category_for_slider_section'));
        $number_of_post = absint(blook_get_option('number_of_home_slider'));
        $image_url ='';
        $get_posts = blook_get_post_query($number_of_post, $post_category);
        if ($get_posts->have_posts()) :
            while ($get_posts->have_posts()) : $get_posts->the_post();
                if (has_post_thumbnail()) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'medium_large');
                    $image_url = $image['0'];
                }
            ?>
                <div class="blook-post blook-post-style-3">
                    <div class="blook-image-section blook-image-640 blook-image-with-content blook-image-hover-effect blook-image-zoom-in-effect blook-overlay">
                        <a href="<?php the_permalink(); ?>"></a>
                        <div class="blook-image bg-image" style="background-image:url('<?php echo esc_url($image_url); ?>')"></div>
                        <?php echo esc_attr(blook_get_post_format(get_the_ID())); ?>

                        <div class="blook-post-desc">
                            <div class="blook-categories blook-categories-with-bg blook-categories-primary-bg">
                                <?php blook_categories_as(); ?>       
                            </div>
                            <h3 class="blook-post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                            <div class="entry-meta blook-meta-tag">
                                <?php
                                    blook_posted_by();
                                    blook_posted_on();
                                ?>
                            </div><!-- .entry-meta -->
                          
                        </div><!--blook-desc-->
                    </div><!--blook-image-section-->
                </div><!--/blook-post-->
            <?php

            endwhile;
        endif;
        wp_reset_postdata();
    }
endif;