<?php
/**
 * Implement theme front page section.
 *
 * @package Blook
 */

if (!function_exists('blook_front_page_component_5')):
    /**
     * Front/Page Style 1
     *
     * @since Blook 1.0.0
     *
     */
    function blook_front_page_component_5()
    { 
        if (1 != blook_get_option('enable_component_5')) {
            return null;
        }
        ?>
        <div class="blook-frontpage-layout-5-section blook-section-border">
            <div class="blook-container">
                <div class="blook-row">
                   
                    <!-- slider post -->
                    <div class="blook-col blook-col-sm-6 blook-col-lg-8">
                        <div class="blook-slider-post-list blook-single-slider">
                            <?php blook_component_5_post_slider(); ?>
                        </div>
                    </div>
                    <!-- post List -->
                    <div class="blook-col blook-col-sm-6 blook-col-lg-4">
                        <div class="blook-post-list blook-post-layout-1">
                            <?php if (!empty(blook_get_option('post_component_5_list_section_title'))) { ?>
                                <h2 class="blook-section-title"><?php echo esc_html(blook_get_option('post_component_5_list_section_title')); ?></h2>
                            <?php } ?>
                            <?php blook_component_5_list_post(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
   <?php }
endif;

add_action('blook_action_front_page_component_5', 'blook_front_page_component_5', 10);

// popular post
if (!function_exists('blook_component_5_list_post')) :
    /**
     * Component-1 Popular Post
     *
     * @since Blook 1.0.0
     *
     */
    function blook_component_5_list_post()
    {
        $post_category = esc_attr(blook_get_option('select_category_for_slider_post_section'));
        $number_of_post = absint(blook_get_option('number_of_slider_post_section'));
        $counter = 1;
        $image_url = '';
        $get_posts = blook_get_post_query($number_of_post, $post_category);
        if ($get_posts->have_posts()) :
            while ($get_posts->have_posts()) : $get_posts->the_post();
                if (has_post_thumbnail()) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'medium_large');
                    $image_url = $image['0'];
                }
            ?>

            <div class="blook-post blook-post-style-4">

                <div class="blook-image-section  blook-image-zoom-in-effect">
                    <a href="<?php the_permalink(); ?>"></a>
                    
		            <div class="blook-image bg-image" style="background-image:url('<?php echo esc_url($image_url); ?>')"></div>
                </div><!--blook-image-section-->

                <div class="blook-desc">
                    <div class="entry-meta blook-meta-tag blook-post-content-opacity blook-text-uppercase">
                        <?php
                            blook_posted_on();
                        ?>
                    </div><!-- .entry-meta -->
                    <h3 class="blook-post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                </div><!--blook-desc-->
                <div class="blook-counter-section blook-post-content-opacity">
                    <?php echo absint($counter); ?>
                </div>
            </div><!--/blook-post-->

            <?php
            $counter++;
            endwhile;

        endif;
        wp_reset_postdata();
    }
endif;


// slider post
if (!function_exists('blook_component_5_post_slider')) :
    /**
     * Component-5 Post Slider
     *
     * @since Blook 1.0.0
     *
     */
    function blook_component_5_post_slider()
    {
        $post_category = esc_attr(blook_get_option('select_category_for_list_post'));
        $number_of_post = absint(blook_get_option('number_of_home_list_post'));
        $image_url = '';
        $get_posts = blook_get_post_query($number_of_post, $post_category);
        if ($get_posts->have_posts()) :
            while ($get_posts->have_posts()) : $get_posts->the_post();
                if (has_post_thumbnail()) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'medium_large');
                    $image_url = $image['0'];
                }
            ?>
                <div class="blook-post blook-post-style-3">
                    <div class="blook-image-section blook-image-with-content blook-image-640 blook-image-border-top-hover-effect  blook-image-zoom-in-effect blook-overlay">
                        <a href="<?php the_permalink(); ?>"></a>
                        <div class="blook-image bg-image" style="background-image:url('<?php echo esc_url($image_url); ?>')"></div>
                        <?php echo esc_attr(blook_get_post_format(get_the_ID())); ?>

                        <div class="blook-post-desc">
                            <?php if( class_exists( 'Booster_Extension_Class' )){
                                blook_post_rating();
                                blook_post_read_time();
                            }?>
                            <div class="blook-categories blook-categories-with-bg blook-categories-primary-bg">
                                <?php blook_categories_as(); ?>       
                            </div>
                            <h3 class="blook-post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                            <div class="entry-meta blook-meta-tag">
                                <?php
                                    blook_posted_by();
                                    blook_posted_on();
                                ?>
                            </div><!-- .entry-meta -->
                            <div class="blook-excerpt blook-limit-excerpt">
                                <?php the_excerpt(); ?>
                            </div>
                            <div class="blook-social-share">
                                <?php if( class_exists( 'Booster_Extension_Class' )){
                                    blook_social_share_option();  
                                }?>
                            </div>
                        </div><!--blook-desc-->
                    </div><!--blook-image-section-->
                </div><!--/blook-post-->
            <?php

            endwhile;
        endif;
        wp_reset_postdata();
    }
endif;