<?php
/**
 * Custom components for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Blook
 */

// Site Identity
if ( ! function_exists( 'blook_logo' ) ) :
    /**
     * Prints HTML with logo.
     */
    function blook_logo() { ?>
    	<div class="site-branding">
            <div class="blook-site-logo">
            <?php if (1 == blook_get_option('enable_site_logo') && !empty(get_theme_mod( 'custom_logo' )) ) {
                the_custom_logo(); 
            }?>
            </div>
            <?php if (1 == blook_get_option('enable_site_title') && !empty(get_bloginfo( 'blogname'))) {
    			if ( is_front_page() && is_home() ) {
    				?>
    				<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
    				<?php
    			} else {
    				?>
    				<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
    				<?php
    			}
            }
			$blook_description = get_bloginfo( 'description', 'display' );
			if ( $blook_description || is_customize_preview() ) :
				?>
                <?php if (1 == blook_get_option('enable_site_tagline') && !empty(get_bloginfo( 'description')) ) { ?>
				    <p class="site-description"><?php echo $blook_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
                <?php } ?>
                <div class="blook-date-section">
                    <span class="blook-icon"><i class="ion ion-md-calendar"></i></span>
                    <span>
                        <?php 
                            echo date_i18n(get_option( 'date_format' )); 
                        ?>
                    </span>
                </div>
			<?php endif; ?>
		</div><!-- .site-branding -->
    <?php }
endif;

// Tag
if( !function_exists( 'blook_top_tages' ) ):

    function blook_top_tages() {

        $latest_post_query = new WP_Query( array( 'post_type' => 'post', 'posts_per_page' => 50, 'post__not_in' => get_option("sticky_posts") ) );
        $tag_lists = array();

        if( $latest_post_query->have_posts() ):

            while( $latest_post_query->have_posts() ):
                $latest_post_query->the_post();

                $tags = get_the_tags( get_the_ID() );

                if( $tags ){

                    foreach( $tags as $tag ){

                        if( !in_array($tag->term_id, $tag_lists) ){
                            
                            $tag_lists[ $tag->term_id ] = $tag->count;

                        }

                    }

                }

            endwhile;

        endif;

        arsort( $tag_lists);

        $blook_default = blook_get_default_theme_options();
        $blook_header_tags = 1;

        if( $blook_header_tags ){

            $blook_header_tags_title = "Tagged";
            $blook_header_tags_count = 7;
            ?>
                <div class="blook-tag-section blook-tags">        
                    <?php if( $blook_header_tags_title ){ ?>
                        <span class="blook-tag-caption">
                           <?php echo esc_html( $blook_header_tags_title ); ?>
                        </span>
                    <?php } ?>

                    <!-- Tag items -->
                    <?php
                    if ($tag_lists) {
                        $count  = 1;
                        foreach( $tag_lists as $key => $value ){


                            $tag = get_tag($key); // <-- your tag ID
                            ?>
                            <a href="<?php echo esc_url(get_tag_link($key)); ?>" class="tags-title-label"><?php echo esc_html($tag->name); ?></a>
                            <?php

                            if( $count == $blook_header_tags_count ){ break; }
                            $count++;
                        }
                    }
                    ?>
                </div>

            <?php
        }

    }

endif;

// Primary Navigation
if ( ! function_exists( 'blook_primary_navigation' ) ) :
    /**
     * Prints HTML primary navigation.
     */
    function blook_primary_navigation() { ?>

    	<nav id="site-navigation" class="main-navigation desktop">
    		<?php
                wp_nav_menu(
                    array(
                        'theme_location' => 'blook-primary-nav',
                        'menu_id'        => 'primary-menu',
                        'menu_class'     => 'blook-nav-menu'
                    )
                );
    		?>
    	</nav><!-- #site-navigation -->
    <?php }
endif;

// Topbar Navigation
if ( ! function_exists( 'blook_top_navigation' ) ) :
    /**
     * Prints HTML top navigation.
     */
    function blook_top_navigation() { ?>
        <nav id="site-top-navigation" class="blook-top-navigation">
            <?php
            wp_nav_menu(
                array(
                    'theme_location' => 'blook-top-nav',
                    'menu_id'        => 'top-menu',
                    'container' => 'div',
                    'menu_class' => 'blook-top-menu'
                )
            );
            ?>
        </nav><!-- #top-navigation -->
    <?php }
endif;

// Date and time
if ( ! function_exists( 'blook_todays_date' ) ) :
    /**
     * Prints HTML with todays date.
     */
    function blook_todays_date() { ?>
        <div class="blook-date-section">
            <span class="blook-icon"><i class="ion ion-md-calendar"></i></span>
            <span>
                <?php 
                    echo date_i18n(get_option( 'date_format' )); 
                ?>
            </span>
        </div>
    <?php }
endif;

// Search Bar
if ( ! function_exists( 'blook_search_bar' ) ) :
    /**
     * Prints HTML with search bar.
     */
    function blook_search_bar() { ?>
        <div class="blook-search-form-section">
            <?php
                get_search_form();
            ?>
        </div><!-- #search-form -->
    <?php }
endif;

// Offcanvas
if ( ! function_exists('blook_offcanvas') ): 
    function blook_offcanvas() { ?>
        <div class="blook-off-canvas">
            <div class="blook-offcanvas-icon">
                <button id="offcanvas" class="offcanvas-btn">
                     <span class="blook-line blook-line-1"></span>
                     <span class="blook-line blook-line-2"></span>
                     <span class="blook-line blook-line-3"></span>
                </button>
            </div>
        </div>
    <?php }
endif;


// Social
if ( ! function_exists('blook_social') ): 
    function blook_social() { ?>
        <div class="blook-social-icon-section">
            <?php
                $blook_fb_link = esc_url(blook_get_option('blook_fb_link'));
                $blook_fb_target = esc_attr(blook_get_option('blook_fb_target'));
                $blook_twt_link = esc_url(blook_get_option('blook_twt_link'));
                $blook_twt_target = esc_attr(blook_get_option('blook_twt_target'));
                $blook_lnkd_link = esc_url(blook_get_option('blook_lnkd_link'));
                $blook_lnkd_target = esc_attr(blook_get_option('blook_lnkd_target'));
                $blook_insta_link = esc_url(blook_get_option('blook_insta_link'));
                $blook_insta_target = esc_attr(blook_get_option('blook_insta_target'));
                $blook_youtube_link = esc_url(blook_get_option('blook_youtube_link'));
                $blook_youtube_target = esc_attr(blook_get_option('blook_youtube_target'));
                $blook_pin_link = esc_url(blook_get_option('blook_pin_link'));
                $blook_pin_target = esc_attr(blook_get_option('blook_pin_target'));
                $blook_tele_link = esc_url(blook_get_option('blook_tele_link'));
                $blook_tele_target = esc_attr(blook_get_option('blook_tele_target'));
            ?>
            <div class="blook-social-icon blook-social-icon-with-bg">
                <?php if($blook_fb_link !=''){ ?>
                    <a class="blook-facebook" <?php if($blook_fb_target == 1) { ?> target="_blank" <?php } ?>href="<?php echo esc_url($blook_fb_link); ?>">
                        <i class="ion ion-logo-facebook"></i>
                    </a>
                <?php } ?>
                <?php if($blook_twt_link !=''){ ?>
                    <a class="blook-twitter" <?php if($blook_twt_target == 1) { ?> target="_blank" <?php } ?>href="<?php echo esc_url($blook_twt_link); ?>">
                        <i class="ion ion-logo-twitter"></i>
                    </a>
                <?php } ?>
                <?php if($blook_lnkd_link !=''){ ?>
                    <a class="blook-linkedin" <?php if($blook_lnkd_target == 1) { ?> target="_blank" <?php } ?>href="<?php echo esc_url($blook_lnkd_link); ?>">
                        <i class="ion ion-logo-linkedin"></i>
                    </a>
                <?php } ?>
                <?php if($blook_insta_link !=''){ ?>
                    <a class="blook-instagram" <?php if($blook_insta_target == 1) { ?> target="_blank" <?php } ?>href="<?php echo esc_url($blook_insta_link); ?>">
                        <i class="ion ion-logo-instagram"></i>
                    </a>
                <?php } ?>
                <?php if($blook_youtube_link !=''){ ?>
                    <a class="blook-youtube" <?php if($blook_youtube_target == 1) { ?> target="_blank" <?php } ?>href="<?php echo esc_url($blook_youtube_link); ?>">
                        <i class="ion ion-logo-youtube"></i>
                    </a>
                <?php } ?>
                <?php if($blook_pin_link !=''){ ?>
                    <a class="blook-pinterest" <?php if($blook_pin_target == 1) { ?> target="_blank" <?php } ?>href="<?php echo esc_url($blook_pin_link); ?>">
                        <i class="ion ion-logo-pinterest"></i>
                    </a>
                <?php } ?>
                <?php if($blook_tele_link !=''){ ?>
                    <a class="blook-telegram" <?php if($blook_tele_target == 1) { ?> target="_blank" <?php } ?>href="<?php echo esc_url($blook_tele_link); ?>">
                        <i class="ion ion-md-send"></i>
                    </a>
                <?php } ?>
            </div>
        </div>
    <?php }
endif;
// Ad space
if ( ! function_exists('blook_ad_section') ): 
    function blook_ad_section() { ?>
        <div class="blook-advertisement-section">
            <a <?php if(blook_get_option('header_advertisement_target') == 1) { ?> target="_blank" <?php } ?> href="<?php echo esc_url(blook_get_option('header_advertisement_url')); ?>">
                <img src="<?php echo esc_url(blook_get_option('header_section_advertisement')); ?>">
            </a>
        </div>
    <?php }
endif;

if (!function_exists('blook_trending_post')) :
    /**
     * Component-1 Trending Post
     *
     * @since Blook 1.0.0
     *
     */
    function blook_trending_post()
    {
        $post_category = esc_attr(blook_get_option('select_category_for_nav_trending_section'));
        $number_of_post = absint(blook_get_option('number_of_home_trending_section_section'));
        $counter = 1;
        $image_url = '';
        $get_posts = blook_get_post_query($number_of_post, $post_category);
        if ($get_posts->have_posts()) :
            while ($get_posts->have_posts()) : $get_posts->the_post();
                if (has_post_thumbnail()) {
                    $image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'medium_large');
                    $image_url = $image['0'];
                }
            ?>
	            <div class="blook-col blook-col-lg-4">
                    <div class="blook-post blook-post-style-4">
        
                        <div class="blook-image-section">
                            <a href="<?php the_permalink(); ?>"></a>
                            
                            <div class="blook-image bg-image" style="background-image:url('<?php echo esc_url($image_url); ?>')"></div>
                        </div><!--blook-image-section-->
        
                        <div class="blook-desc">
                            <div class="entry-meta blook-meta-tag blook-post-content-opacity blook-text-uppercase">
                                <?php
                                    blook_posted_on();
                                ?>
                            </div><!-- .entry-meta -->
                            <h3 class="blook-post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                        </div><!--blook-desc-->
                        <div class="blook-counter-section blook-post-content-opacity">
                            <?php echo absint($counter); ?>
                        </div>
                    </div><!--/blook-post-->
				</div>

            <?php
            $counter++;
            endwhile;

        endif;
        wp_reset_postdata();
    }
endif;



