<?php
// get theme option
if ( ! function_exists( 'blook_get_option' ) ) :

	/**
	 * Get theme option.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Option key.
	 * @return mixed Option value.
	 */
	function blook_get_option( $key ) {

		if ( empty( $key ) ) {
			return;
		}

		$value = '';

		$default = blook_get_default_theme_options();
		$default_value = null;

		if ( is_array( $default ) && isset( $default[ $key ] ) ) {
			$default_value = $default[ $key ];
		}

		if ( null !== $default_value ) {
			$value = get_theme_mod( $key, $default_value );
		}
		else {
			$value = get_theme_mod( $key );
		}

		return $value;
	}

endif;

/**
 * Default theme options.
 *
 * @package Blook
 */

if ( ! function_exists( 'blook_get_default_theme_options' ) ) :

	/**
	 * Get default theme options
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
	function blook_get_default_theme_options() {

		$defaults = array();
		//home page section
		$defaults['show_selected_page_content_on_homepage']		= 1;
		$defaults['show_latest_post_content_on_homepage']		= 1;

		// global
		$defaults['choose_slider_arrow']			= "blook-slick-angle-right";
		$defaults['select_offcanvas_location']			= "blook-off-top-bar";
		// site identity option
		$defaults['enable_site_logo']				= 1;
		$defaults['enable_site_title']				= 1;
		$defaults['enable_site_tagline']			= 1;

		// Header top bar
		$defaults['enable_topbar_section']			= 1;
		$defaults['select_top_bar_layout']			= 'blook-topbar-layout-4';
		
		// Header section
		$defaults['select_header_layout']			= 'blook-header-layout-1';
		$defaults['header_section_advertisement']			= '';
		$defaults['header_advertisement_url']			= '';
		// Header navigation
		$defaults['select_navbar_layout']				= 'blook-navbar-layout-1';
		$defaults['enable_site_mode_switcher_nav_section']	= 1;
		$defaults['enable_subscription_on_nav_section']	= 1;
		$defaults['subscription_image_upload']			= '';
		$defaults['mailchimp_subscription_title']		= esc_html__( 'Subscribe Now', 'blook' );
		$defaults['mailchimp_subscription_shortcode']	= '';
		$defaults['enable_trending_on_nav_section']		= 1;
		$defaults['nav_trending_button_text']			= esc_html__( 'Trending Now', 'blook' );
		$defaults['nav_trending_section_title']					= esc_html__( 'Most Viewed This Week', 'blook' );
		$defaults['select_category_for_nav_trending_section']	= 0;
		$defaults['number_of_home_trending_section_section']	= 6;
		
		// component style 1
		$defaults['enable_component_1']							= '';
		$defaults['blook_recent_post_section_title']			= esc_html__( 'Recent News', 'blook' );
		$defaults['select_category_for_recent_post_section']	= '';
		$defaults['number_of_home_recent_post_section']			= 5;
		$defaults['blook_post_grid_section']					= esc_html__( 'Trending Today', 'blook' );
		$defaults['select_category_for_post_grid']				= '';
		$defaults['number_of_home_post_grid']					= 5;
		$defaults['enable_grid_post_excerpt']					= 1;
		$defaults['excerpt_home_post_grid']						= 20;
		$defaults['select_category_for_slider_section']			= '';
		$defaults['number_of_home_slider']						= 5;
		
		// component style 2
		$defaults['enable_component_2']							= '';
		$defaults['blook_component_2_title']					= esc_html__( 'Layout Style 2', 'blook' );
		$defaults['select_category_for_component_2_section']	= '';
		$defaults['number_of_post_on_component_2_section']		= 8;
		$defaults['component_2_add_image']						= '';
		$defaults['component_2_add_url']						= '';
		$defaults['component_2_read_more']						= esc_html__( 'Read More', 'blook' );
		
		// component style 3
		$defaults['enable_component_3']							= '';
		$defaults['select_category_for_component_3_section']	= '';
		$defaults['number_of_post_on_component_3_section']		= 8;
		$defaults['enable_component_3_description']				= '';
		$defaults['component_3_section_layout']					= 'blook-full-width-carousel-slider';
		
		// component style 4
		$defaults['enable_component_4']							= '';
		$defaults['blook_component_4_title']					= esc_html__( 'Layout Style 4', 'blook' );
		$defaults['select_category_for_component_4_section']	= '';
		$defaults['number_of_post_on_component_4_section']		= 8;
		$defaults['component_4_read_more']						= esc_html__( 'Read More', 'blook' );

		// component style 5
		$defaults['enable_component_5']							= '';
		$defaults['select_category_for_slider_post_section']	= '';
		$defaults['number_of_slider_post_section']				= 3;
		$defaults['post_component_5_list_section_title']		= esc_html__( 'Featured Now', 'blook' );
		$defaults['select_category_for_list_post']				= '';
		$defaults['number_of_home_list_post']					= 8;

        // breaking news
        $defaults['enable_breaking_news_section']				= 1;
        $defaults['blook_breaking_news_title']              	= esc_html__('Breaking News','blook');
        $defaults['select_category_for_breaking_news_section']  = 0;
        $defaults['number_of_post_on_breaking_news_section']   	= 7;


        // Pagination
        $defaults['blook_pagination_layout']			= 'numeric';

        // Post Setting
		$defaults['ed_post_author']                             = 1;
		$defaults['ed_post_date']                               = 1;
		$defaults['ed_comment_count']                           = 1;
		$defaults['ed_post_category']                           = 1;
		$defaults['ed_post_type']                           	= 1;
		$defaults['ed_post_excerpt']            				= 1;
        $defaults['post_read_more_button_text']                 = esc_html__('Read More','blook');
		$defaults['ed_post_rating']            					= 1;
		$defaults['ed_post_read_time']            				= 1;
		$defaults['ed_post_social_share']            			= 1;

		// Single Post
		$defaults['ed_related_post']                            = 1;
        $defaults['related_post_title']                         = esc_html__('Related Post','blook');
        $defaults['ed_floating_next_previous_nav']               = 1;

		// Archive Post
		$defaults['select_archive_layout']                      = '1';

        // Sidebar
        $defaults['global_sidebar_layout_sidebar']               = 'no-sidebar';
        $defaults['single_post_sidebar']               = 'global-sidebar';
        // Preloader
        $defaults['ed_preloader']                            = 1;

		// Footer
		$defaults['footer_column_layout']           = 3;
        $defaults['footer_copyright_text']          = esc_html__( 'All rights reserved.', 'blook' );

        $defaults['home_section_reorder_val']      	=  'conponent_1_setting_option,conponent_2_setting_option,conponent_3_setting_option,conponent_4_setting_option,conponent_5_setting_option';

        
		// Pass through filter.
		$defaults = apply_filters( 'blook_filter_default_theme_options', $defaults );

		return $defaults;

	}

endif;