<?php
/**
 * Theme Header Section.
 *
 * @package Blook
 */

$default = blook_get_default_theme_options();

// Add Theme Header Options Panel.
$wp_customize->add_panel('theme_header_option_panel',
    array(
        'title' => esc_html__('Header Section', 'blook'),
        'priority' => 30,
        'capability' => 'edit_theme_options',
    )
);

// Top Bar Section.
$wp_customize->add_section('top_bar_section_settings',
    array(
        'title' => esc_html__('Top Bar Section Settings', 'blook'),
        'priority' => 20,
        'capability' => 'edit_theme_options',
        'panel' => 'theme_header_option_panel',
    )
);

$wp_customize->add_setting('enable_topbar_section',
    array(
        'default' => $default['enable_topbar_section'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_checkbox',
    )
);

$wp_customize->add_control('enable_topbar_section',
    array(
        'label' => esc_html__('Enable Topbar Section', 'blook'),
        'section' => 'top_bar_section_settings',
        'type' => 'checkbox',
        'priority' => 22,

    )
);


// Add top bar layout setting.
$wp_customize->add_setting('select_top_bar_layout',
    array(
        'default' => $default['select_top_bar_layout'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_select',
    )
);

$wp_customize->add_control(new Blook_Radio_Image_Control($wp_customize, 'select_top_bar_layout',
        array(
            'label' => esc_html__('Select Top Bar Layout', 'blook'),
            'section' => 'top_bar_section_settings',
            'priority' => 180,
            'choices' => array(
                'blook-topbar-layout-1' => esc_url(get_template_directory_uri() . '/assets/img/blook-top-bar-layout-1.png'),
                'blook-topbar-layout-2' => esc_url(get_template_directory_uri() . '/assets/img/blook-top-bar-layout-2.png'),
                'blook-topbar-layout-3' => esc_url(get_template_directory_uri() . '/assets/img/blook-top-bar-layout-3.png'),
                'blook-topbar-layout-4' => esc_url(get_template_directory_uri() . '/assets/img/blook-top-bar-layout-4.png'),
            ),
            'active_callback' => 'blook_topbar_section_status',
        )
    )
);

// Header Layout Setting
$wp_customize->add_section('header_layout_settings',
    array(
        'title' => esc_html__('Header Layout', 'blook'),
        'capability' => 'edit_theme_options',
        'panel' => 'theme_header_option_panel',
    )
);

$wp_customize->add_setting('select_header_layout',
    array(
        'default' => $default['select_header_layout'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_select',
    )
);

$wp_customize->add_control(new Blook_Radio_Image_Control($wp_customize, 'select_header_layout',
        array(
            'label' => esc_html__('Select Header Layout', 'blook'),
            'section' => 'header_layout_settings',
            'choices' => array(
                'blook-header-layout-1' => esc_url(get_template_directory_uri() . '/assets/img/blook-header-layout-1.png'),
                'blook-header-layout-2' => esc_url(get_template_directory_uri() . '/assets/img/blook-header-layout-2.png'),
                'blook-header-layout-3' => esc_url(get_template_directory_uri() . '/assets/img/blook-header-layout-3.png'),
            )
        )
    )
);

// Setting header_section_advertisement.
$wp_customize->add_setting('header_section_advertisement',
    array(
        'default'           => $default['header_section_advertisement'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_image',
    )
);
$wp_customize->add_control(
    new WP_Customize_Image_Control($wp_customize, 'header_section_advertisement',
        array(
            'label'       => esc_html__('Header Advertisement', 'blook'),
            'description' => sprintf(esc_html__('Recommended Size %1$s px X %2$s px', 'blook'), 970, 90),
            'section'     => 'header_layout_settings',
            'priority'    => 120,
            'active_callback' => 'blook_header_layout_2',
        )
    )
);

/*header_advertisement_url*/
$wp_customize->add_setting('header_advertisement_url',
    array(
        'default'           => $default['header_advertisement_url'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control('header_advertisement_url',
    array(
        'label'    => esc_html__('Header Advertisement URL', 'blook'),
        'section'  => 'header_layout_settings',
        'type'     => 'text',
        'priority' => 130,
        'active_callback' => 'blook_header_layout_2',
    )
);


$wp_customize->add_setting('header_advertisement_target',
    array(
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_checkbox',
    )
);
$wp_customize->add_control('header_advertisement_target',
    array(
        'label' => esc_html__('Open Advertisement in a new tab', 'blook'),
        'section' => 'header_layout_settings',
        'priority' => 130,
        'type' => 'checkbox',
        'active_callback' => 'blook_header_layout_2',
    )
);

// Navigation Bar Setting
$wp_customize->add_section('navbar_layout_settings',
    array(
        'title' => esc_html__('Navbar Layout', 'blook'),
        'capability' => 'edit_theme_options',
        'panel' => 'theme_header_option_panel',
    )
);

$wp_customize->add_setting('select_navbar_layout',
    array(
        'default' => $default['select_navbar_layout'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_select',
    )
);

$wp_customize->add_control('select_navbar_layout',
    array(
        'label' => esc_html__('Select Navbar Icon Alignment', 'blook'),
        'section' => 'navbar_layout_settings',
        'type' => 'select',
        'choices'     => array(
                'blook-navbar-layout-1' => esc_html__('Icon - Button - Icon','blook'),
                'blook-navbar-layout-2' => esc_html__('Icon - Icon - Button','blook'),
            ),
        'priority' => 22,

    )
);

$wp_customize->add_setting('enable_site_mode_switcher_nav_section',
    array(
        'default' => $default['enable_site_mode_switcher_nav_section'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_checkbox',
    )
);

$wp_customize->add_control('enable_site_mode_switcher_nav_section',
    array(
        'label' => esc_html__('Enable Site Mode Switcher on Nav-Bar', 'blook'),
        'section' => 'navbar_layout_settings',
        'type' => 'checkbox',
        'priority' => 100,

    )
);
$wp_customize->add_setting('enable_subscription_on_nav_section',
    array(
        'default' => $default['enable_subscription_on_nav_section'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_checkbox',
    )
);

$wp_customize->add_control('enable_subscription_on_nav_section',
    array(
        'label' => esc_html__('Enable Subscribe Button on Nav-Bar', 'blook'),
        'section' => 'navbar_layout_settings',
        'type' => 'checkbox',
        'priority' => 100,

    )
);


// Setting subscription_image_upload.
$wp_customize->add_setting('subscription_image_upload',
    array(
        'default'           => $default['subscription_image_upload'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_image',
    )
);
$wp_customize->add_control(
    new WP_Customize_Image_Control($wp_customize, 'subscription_image_upload',
        array(
            'label'       => esc_html__('Upload Image for Subscription', 'blook'),
            'description' => sprintf(esc_html__('Recommended Size %1$s px X %2$s px', 'blook'), 400, 400),
            'section'     => 'navbar_layout_settings',
            'priority'    => 100,
            'active_callback' => 'blook_subscription_on_nav_section',
        )
    )
);


// Setting mailchimp_subscription_title.
$wp_customize->add_setting( 'mailchimp_subscription_title',
    array(
    'default'           => $default['mailchimp_subscription_title'],
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control( 'mailchimp_subscription_title',
    array(
    'label'    => __( 'Mailchimp Subscription Title', 'blook' ),
    'section'  => 'navbar_layout_settings',
    'type'     => 'text',
    'priority' => 100,
    'active_callback' => 'blook_subscription_on_nav_section',

    )
);

// Setting mailchimp_subscription_shortcode.
$wp_customize->add_setting( 'mailchimp_subscription_shortcode',
    array(
    'default'           => $default['mailchimp_subscription_shortcode'],
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control( 'mailchimp_subscription_shortcode',
    array(
    'label'    => __( 'Mailchimp Subscription Shortcode', 'blook' ),
    'section'  => 'navbar_layout_settings',
    'type'     => 'text',
    'priority' => 100,
    'active_callback' => 'blook_subscription_on_nav_section',

    )
);

$wp_customize->add_setting( 'nav_trending_button_text',
    array(
        'default'           => $default['nav_trending_button_text'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control( 'nav_trending_button_text',
    array(
        'label'    => __( 'Nav Trending Button Text', 'blook' ),
        'section'  => 'navbar_layout_settings',
        'type'     => 'text',
        'priority' => 100,
    )
);


$wp_customize->add_setting('enable_trending_on_nav_section',
    array(
        'default' => $default['enable_trending_on_nav_section'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_checkbox',
    )
);

$wp_customize->add_control('enable_trending_on_nav_section',
    array(
        'label' => esc_html__('Enable Trending Button on Nav-Bar', 'blook'),
        'section' => 'navbar_layout_settings',
        'type' => 'checkbox',
        'priority' => 100,

    )
);


$wp_customize->add_setting( 'nav_trending_button_text',
    array(
        'default'           => $default['nav_trending_button_text'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control( 'nav_trending_button_text',
    array(
        'label'    => __( 'Nav Trending Button Text', 'blook' ),
        'section'  => 'navbar_layout_settings',
        'type'     => 'text',
        'priority' => 100,
        'active_callback' => 'blook_trending_on_nav_section',
    )
);


$wp_customize->add_setting( 'nav_trending_section_title',
    array(
        'default'           => $default['nav_trending_section_title'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control( 'nav_trending_section_title',
    array(
        'label'    => __( 'Nav Trending Section Title', 'blook' ),
        'section'  => 'navbar_layout_settings',
        'type'     => 'text',
        'priority' => 100,
        'active_callback' => 'blook_trending_on_nav_section',
    )
);


// Setting - drop down category for trending post section.
$wp_customize->add_setting( 'select_category_for_nav_trending_section',
    array(
        'default'           => $default['select_category_for_nav_trending_section'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'absint',
    )
);
$wp_customize->add_control( new Blook_Dropdown_Taxonomies_Control( $wp_customize, 'select_category_for_nav_trending_section',
    array(
        'label'           => __( 'Category for Trending Post Section', 'blook' ),
        'description'     => __( 'Select category to be shown on trending Post section on nav-bar', 'blook' ),
        'section'         => 'navbar_layout_settings',
        'type'            => 'dropdown-taxonomies',
        'taxonomy'        => 'category',
        'priority'        => 100,
        'active_callback' => 'blook_trending_on_nav_section',
    ) ) );

$wp_customize->add_setting( 'number_of_home_trending_section_section',
    array(
        'default'           => $default['number_of_home_trending_section_section'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_positive_integer',
    )
);
$wp_customize->add_control( 'number_of_home_trending_section_section',
    array(
        'label'    => __( 'Select Post Number on Trending Section', 'blook' ),
        'section'  => 'navbar_layout_settings',
        'type'     => 'number',
        'priority' => 100,
        'input_attrs'     => array( 'min' => 3, 'max' => 9, 'style' => 'width: 150px;' ),
        'active_callback' => 'blook_trending_on_nav_section',
    )
);

// offcanvas Section.
$wp_customize->add_section('off_canvas_setting',
    array(
        'title' => esc_html__('Off-Canvas Section Position', 'blook'),
        'capability' => 'edit_theme_options',
        'panel' => 'theme_header_option_panel',
    )
);

$wp_customize->add_setting('select_offcanvas_location',
    array(
        'default' => $default['select_offcanvas_location'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'blook_sanitize_select',
    )
);

$wp_customize->add_control('select_offcanvas_location',
    array(
        'label' => esc_html__('Enable Topbar Section', 'blook'),
        'section' => 'off_canvas_setting',
        'type' => 'select',
        'choices'     => array(
                'blook-off-top-bar' => esc_html__('Top Bar Section','blook'),
                'blook-off-heading' => esc_html__('Header Section (Logo Section)','blook'),
            ),
        'priority' => 22,

    )
);

