<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Blook
 */

if ( ! function_exists( 'blook_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function blook_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( ' %s', 'post date', 'blook' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);
	?>
		<span class="entry-meta-item entry-meta-date">
			<span class="blook-meta-icon"><i class="ion ion-md-calendar"></i></span>
			<span class="posted-on blook-meta-caption"><?php echo $posted_on; ?></span>
		</span>

	<?php }
endif;

if ( ! function_exists( 'blook_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function blook_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( '%s', 'post author', 'blook' ),
			'<span class="blook-author-image"><img src="'. esc_url(get_avatar_url(get_the_author_meta( 'ID' ), array("size"=>50))) .'"></span><a class="url fn n blook-meta-caption" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>'
		);

		echo '<span class="byline entry-meta-item entry-meta-author"> ' . $byline . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

	}
endif;


if ( ! function_exists( 'blook_comment_count' ) ) :
/**
 * Prints HTML with meta information for the current author.
 */
function blook_comment_count($post_id) {
    $show_comment_count = 1;
    if ($show_comment_count == 1):

        $comment_count = get_comments_number($post_id);
        if (absint($comment_count) >= 1):
        ?>
        <span class="entry-meta-item entry-meta-comment">
			<span class="blook-meta-icon"><i class="ion ion-ios-text"></i></span>
			<a class="blook-meta-caption" href="<?php the_permalink(); ?>">
				<?php echo get_comments_number($post_id); ?>
			</a>
        </span>
    <?php endif;
    endif;
}
endif;



if ( ! function_exists( 'blook_categories_as' ) ) :
/**
 * Prints HTML with meta information for the current author.
 */
function blook_categories_as() {
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list();
		if ( $categories_list ) {
			/* translators: 1: list of categories. */
			echo(  $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}
}
endif;


/**
 * Returns post foramt icon.
 *
 * @since  blook 1.0.0
 */
if (!function_exists('blook_get_post_format')):
    function blook_get_post_format($post_id)
    {
        $post_format = get_post_format($post_id);
        switch ($post_format) {
            case "image":
				$post_format = "<span class='blook-post-format-icon'><i class='ion ion-ios-camera'></i></span>";
                break;
            case "video":
				$post_format = "<span class='blook-post-format-icon'><i class='ion ion-ios-videocam'></i></span>";
                break;
            case "gallery":
				$post_format = "<span class='blook-post-format-icon'><i class='ion ion-md-images'></i></span>";
                break;
            case "quote":
				$post_format = "<span class='blook-post-format-icon'><i class='ion ion-md-quote'></i></span>";
                break; 
           case "audio":
				$post_format = "<span class='blook-post-format-icon'><i class='ion ion-ios-musical-notes'></i></span>";
                break;
            default:
                $post_format = "";
        }

        echo $post_format;
    }

endif;

if ( ! function_exists( 'blook_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function blook_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ' ', 'list item separator', 'blook' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links"><span class="blook-tag-caption">Tagged</span>' . esc_html__( ' %1$s', 'blook' ) . '</span>', $tags_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'blook' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					wp_kses_post( get_the_title() )
				)
			);
			echo '</>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'blook' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				wp_kses_post( get_the_title() )
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'blook_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function blook_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

			<div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
			</div><!-- .post-thumbnail -->

		<?php else : ?>

			<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
				<?php
					the_post_thumbnail(
						'post-thumbnail',
						array(
							'alt' => the_title_attribute(
								array(
									'echo' => false,
								)
							),
						)
					);
				?>
			</a>

			<?php
		endif; // End is_singular().
	}
endif;

if ( ! function_exists( 'wp_body_open' ) ) :
	/**
	 * Shim for sites older than 5.2.
	 *
	 * @link https://core.trac.wordpress.org/ticket/12563
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
endif;
